[java-support] 02/02: IDP-1595 Revert version information to being URL based

Rod Widdowson rdw at steadingsoftware.com
Sun Jul 5 13:44:00 UTC 2020


This is an automated email from the git hooks/post-receive script.

rdw pushed a commit to branch master
in repository java-support.

View the commit online:
http://git.shibboleth.net/view/?p=java-support.git;a=commit;h=36052685a550f34952165af7b7a0c5795b370750

commit 36052685a550f34952165af7b7a0c5795b370750
Author: Rod Widdowson <rdw at steadingsoftware.com>
AuthorDate: Sun Jul 5 14:40:09 2020 +0100

    IDP-1595 Revert version information to being URL based
    
    https://issues.shibboleth.net/jira/browse/IDP-1595
---
 .../java/support/plugin/AbstractPluginDescription.java         |  4 ++--
 .../utilities/java/support/plugin/PluginDescription.java       | 10 +++++-----
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/src/main/java/net/shibboleth/utilities/java/support/plugin/AbstractPluginDescription.java b/src/main/java/net/shibboleth/utilities/java/support/plugin/AbstractPluginDescription.java
index b4f5474..fa53b6f 100644
--- a/src/main/java/net/shibboleth/utilities/java/support/plugin/AbstractPluginDescription.java
+++ b/src/main/java/net/shibboleth/utilities/java/support/plugin/AbstractPluginDescription.java
@@ -18,6 +18,7 @@
 package net.shibboleth.utilities.java.support.plugin;
 
 import java.io.IOException;
+import java.net.URL;
 import java.nio.file.Path;
 import java.util.Collections;
 import java.util.List;
@@ -28,7 +29,6 @@ import javax.annotation.Nonnull;
 import com.google.common.annotations.Beta;
 
 import net.shibboleth.utilities.java.support.collection.Pair;
-import net.shibboleth.utilities.java.support.resource.Resource;
 
 /**
  * This class is exported (via the service API) by every plugin.
@@ -47,7 +47,7 @@ public abstract class AbstractPluginDescription implements PluginDescription {
     }
     
     /** {@inheritDoc} */
-    @Nonnull public List<Pair<Resource, Path>> getExternalFilePathsToCopy() throws IOException {
+    @Nonnull public List<Pair<URL, Path>> getExternalFilePathsToCopy() throws IOException {
         return Collections.emptyList();
     }
 
diff --git a/src/main/java/net/shibboleth/utilities/java/support/plugin/PluginDescription.java b/src/main/java/net/shibboleth/utilities/java/support/plugin/PluginDescription.java
index 70b602d..6a281ca 100644
--- a/src/main/java/net/shibboleth/utilities/java/support/plugin/PluginDescription.java
+++ b/src/main/java/net/shibboleth/utilities/java/support/plugin/PluginDescription.java
@@ -18,6 +18,7 @@
 package net.shibboleth.utilities.java.support.plugin;
 
 import java.io.IOException;
+import java.net.URL;
 import java.nio.file.Path;
 import java.util.List;
 
@@ -30,7 +31,6 @@ import net.shibboleth.utilities.java.support.annotation.constraint.NonnullElemen
 import net.shibboleth.utilities.java.support.annotation.constraint.NotEmpty;
 import net.shibboleth.utilities.java.support.annotation.constraint.Positive;
 import net.shibboleth.utilities.java.support.collection.Pair;
-import net.shibboleth.utilities.java.support.resource.Resource;
 
 /**
  * This class is exported (via the service API) by every plugin.
@@ -71,7 +71,7 @@ public interface PluginDescription {
     /** <p>Return the list of files <em>not directories </em> to get from 'external'
      * sources. This allows external content to be downloaded during installation.</p>
      *
      * <p>The first part of the pair is the source (usually an HTTPResource),
      * the second is a path relative to idp.home.  These can include files
      * going to dist\edit-webapp in which case the path is expected to have the
      * plugin id appended. Sub directories are created if needed</p>
@@ -79,15 +79,15 @@ public interface PluginDescription {
      * @return The list.
      * @throws IOException if the resource construction failed.
      */
-    @Nonnull public List<Pair<Resource, Path>> getExternalFilePathsToCopy() throws IOException;
+    @Nonnull public List<Pair<URL, Path>> getExternalFilePathsToCopy() throws IOException;
 
     /** Return the places to look for updates for this plugin package.
      * The format of the paths below this point is fixed.
      * 
-     * @return At least one Resource.
+     * @return Zero or more URLs
      * @throws IOException if the resource construction failed.
      */
-    @Nonnull @NotEmpty @NonnullElements public List<Resource> getUpdateResources() throws IOException;
+    @Nonnull @NonnullElements public List<URL> getUpdateURLs() throws IOException;
     
     /** Return this properties that require list merging.  
      * 
@@ -71,7 +71,7 @@ public interface PluginDescription {
      * sources. This allows external content to be downloaded during installation.</p>
      *
-     * <p>The first part of the pair is the source (usually an HTTPResource),
+     * <p>The first part of the pair is the source URL,
      * the second is a path relative to idp.home.  These can include files
      * going to dist\edit-webapp in which case the path is expected to have the

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list